@@ -48,6 +48,7 @@
 #include <QScreen>
 #include <QTimer>
 #include <QtMath>
+#include <qobjectdefs.h>
 #include <utility>
 
 SpectacleCore *SpectacleCore::s_self = nullptr;
@@ -107,6 +108,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
 
     m_platform = loadPlatform();
     m_videoPlatform = loadVideoPlatform();
+    m_videoPlatform->setExtension(Settings::videoFormat());
     auto platform = m_platform.get();
     m_annotationDocument = std::make_unique<AnnotationDocument>(new AnnotationDocument(this));
 
@@ -115,13 +117,17 @@ SpectacleCore::SpectacleCore(QObject *parent)
     connect(this, &SpectacleCore::grabDone, this, [this](const QImage &image,
                                                          const ExportManager::Actions &actions){
         deleteWindows();
-        const auto &exportActions = actions == ExportManager::NoActions ? autoExportActions() : actions;
-        onScreenshotUpdated(image, exportActions);
+        onScreenshotUpdated(image);
+        syncExportImage();
+        const auto &exportActions = actions & ExportManager::AnyAction ? actions : autoExportActions();
+        ExportManager::instance()->exportImage(exportActions, outputUrl());
     });
 
     connect(platform, &Platform::newScreenshotTaken, this, [this](const QImage &image){
         m_annotationDocument->clearAnnotations();
-        onScreenshotUpdated(image, autoExportActions());
+        onScreenshotUpdated(image);
+        syncExportImage();
+        ExportManager::instance()->exportImage(autoExportActions(), outputUrl());
         setVideoMode(false);
     });
     connect(platform, &Platform::newScreensScreenshotTaken, this, [this](const QVector<CanvasImage> &screenImages) {
@@ -146,7 +152,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
     // set up the export manager
     auto exportManager = ExportManager::instance();
     auto onImageExported = [this](const ExportManager::Actions &actions, const QUrl &url) {
-        if (Settings::quitAfterSaveCopyExport()) {
+        if (actions & ExportManager::UserAction && Settings::quitAfterSaveCopyExport()) {
             deleteWindows();
         }
 
@@ -534,13 +540,17 @@ void SpectacleCore::takeNewScreenshot(Platform::GrabMode grabMode, int timeout,
 
     const bool noDelay = timeout == 0;
 
-    if (PlasmaVersion::get() < PlasmaVersion::check(5, 27, 5)) {
+    if (PlasmaVersion::get() < PlasmaVersion::check(5, 27, 4) && KX11Extras::compositingActive()) {
         // when compositing is enabled, we need to give it enough time for the window
         // to disappear and all the effects are complete before we take the shot. there's
         // no way of knowing how long the disappearing effects take, but as per default
         // settings (and unless the user has set an extremely slow effect), 200
         // milliseconds is a good amount of wait time.
-        timeout = qMax(timeout, KX11Extras::compositingActive() ? 200 : 50);
+        timeout = qMax(timeout, 200);
+    } else if (KWindowSystem::isPlatformX11()) {
+        // Minimum 50ms delay to prevent segfaults from xcb function calls
+        // that don't get replies fast enough.
+        timeout = qMax(timeout, 50);
     }
 
     if (noDelay) {
@@ -587,17 +597,12 @@ void SpectacleCore::showErrorMessage(const QString &message)
     }
 }
 
-void SpectacleCore::onScreenshotUpdated(const QImage &image, const ExportManager::Actions &actions)
+void SpectacleCore::onScreenshotUpdated(const QImage &image)
 {
-    using Option = CommandLineOptions::Option;
-    using Action = ExportManager::Action;
-
     m_annotationDocument->clearImages();
-
-    auto exportManager = ExportManager::instance();
-    exportManager->setImage(image);
     m_annotationDocument->addImage(image);
-    exportManager->updateTimestamp();
+    ExportManager::instance()->setImage(image);
+    ExportManager::instance()->updateTimestamp();
 
     if (m_startMode == StartMode::Gui) {
         if (image.isNull()) {
@@ -606,22 +611,13 @@ void SpectacleCore::onScreenshotUpdated(const QImage &image, const ExportManager
             return;
         }
         initViewerWindow(ViewerWindow::Image);
-        if (m_cliOptions[Option::EditExisting]) {
+        if (m_cliOptions[CommandLineOptions::EditExisting]) {
             ViewerWindow::instance()->setAnnotating(true);
         }
         ViewerWindow::instance()->setVisible(true);
         auto titlePreset = !image.isNull() ? SpectacleWindow::Unsaved : SpectacleWindow::Saved;
         SpectacleWindow::setTitleForAll(titlePreset);
     }
-
-    syncExportImage();
-    if (actions & Action::Save && m_cliOptions[Option::Output]) {
-        exportManager->exportImage(actions, m_outputUrl);
-    } else if (actions & Action::Save && m_cliOptions[Option::EditExisting]) {
-        exportManager->exportImage(actions, m_editExistingUrl);
-    } else {
-        exportManager->exportImage(actions, outputUrl());
-    }
 }
 
 void SpectacleCore::onScreenshotFailed()
@@ -648,6 +644,10 @@ static QVector<KNotification *> notifications;
 
 void SpectacleCore::doNotify(const ExportManager::Actions &actions, const QUrl &saveUrl)
 {
+    if (m_cliOptions[CommandLineOptions::NoNotify]) {
+        return;
+    }
+
     // ensure program stays alive until the notification finishes.
     if (!m_eventLoopLocker) {
         m_eventLoopLocker = std::make_unique<QEventLoopLocker>();
@@ -960,3 +960,27 @@ QString SpectacleCore::timeFromMilliseconds(qint64 milliseconds) const
     }
     return KFormat().formatDuration(milliseconds, options);
 }
+
+QStringList SpectacleCore::supportedVideoFormats() const
+{
+    return m_videoPlatform->suggestedExtensions();
+}
+
+void SpectacleCore::setVideoFormat(const QString &format)
+{
+    if (format == Settings::videoFormat()) {
+        return;
+    }
+
+    m_videoPlatform->setExtension(format);
+    Settings::setVideoFormat(m_videoPlatform->extension());
+
+    Q_EMIT videoFormatChanged(format);
+}
+
+QString SpectacleCore::videoFormat() const
+{
+    return m_videoPlatform->extension();
+}
+
+#include "moc_SpectacleCore.cpp"
